//+------------------------------------------------------------------+
//|                                                   RSI_EA_V01.mq5 |
//|                        Copyright 2022, MetaQuotes Software Corp. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#include <Trade\PositionInfo.mqh>
#include<Trade\Trade.mqh>
//Create an instance of Ctrade
CTrade trade;
CPositionInfo  m_position;             // object of CPositionInfo class
//--- input parameters
input int      RSIPeriod=14;
input int OverBuy=70;
input int OverSell=30;
input double   Lot=0.01;
input double   InpProfitInMoney  = 2;  // Profit in money
input int      StopLoss=1000;
input int      NextPosition=500;
input double   Increament=1.5;


void OnTick()
  {
double NextLotsize = NormalizeDouble(Lot*Increament,2);
// we calculate the Ask price
double Ask=NormalizeDouble(SymbolInfoDouble (_Symbol,SYMBOL_ASK) ,_Digits) ;
// we calculate the Bid price
double Bid=NormalizeDouble(SymbolInfoDouble (_Symbol,SYMBOL_BID),_Digits);
//Get Balance
double Balance=AccountInfoDouble(ACCOUNT_BALANCE);
//Get Equity
double Equity=AccountInfoDouble(ACCOUNT_EQUITY);
 // create a string for the signal
string signal="";
// create an array for the price data 
double MyRSIArray [] ;

// sort the array from the current candle downwards
ArraySetAsSeries (MyRSIArray, true) ;

// define the properties for the RSI
int MyRSIDefinition = iRSI(_Symbol,_Period,RSIPeriod,PRICE_CLOSE);

// Defined EA, from current candle, for 3 candles, save in array 
CopyBuffer (MyRSIDefinition, 0,0,3, MyRSIArray) ;
// calculate the current RSI value
double MyRSIValue=NormalizeDouble(MyRSIArray[0],2);

if (MyRSIValue>OverBuy)
    signal="sell";
if (MyRSIValue<OverSell)
    signal="buy";

// sell 10 Microlot
if (signal =="sell" && PositionsTotal()<1)
{
   trade.Sell(Lot, NULL,Bid, (Bid+StopLoss *_Point), 0,NULL); // start position (Bid-TakeProfit *_Point)
  
   SellLimit(Bid+StopLoss *_Point,Bid,NextLotsize);
 }
// Buy 10 Microlot
if (signal == "buy" && PositionsTotal () <1) 
 {
  trade.Buy(Lot ,NULL,Ask, (Ask-StopLoss *_Point), 0,NULL); //(Ask+TakeProfit *_Point)
  Buylimit(Ask-StopLoss *_Point,Ask,NextLotsize);
 }

CloseProfitInMoney(); //Close profit for Fist Position

}

// set Buy limit position
void Buylimit(double SLbuylimit,double TPbuylimit,double Lotsize)
{
// we calculate the Ask price
double Ask=NormalizeDouble(SymbolInfoDouble (_Symbol,SYMBOL_ASK) ,_Digits) ;
// we calculate the Bid price
double Bid=NormalizeDouble(SymbolInfoDouble (_Symbol,SYMBOL_BID),_Digits);
trade.BuyLimit
 (
  Lotsize,                  //lot size
  (Ask-(NextPosition*_Point)),   // Price for buy limit
  _Symbol,              // Get symbol
  SLbuylimit,                    //Stop loss
  TPbuylimit,   // Take profit (Ask+(200*_Point))
  ORDER_TIME_GTC,       // Expiration date
  0,                    // Expiration time
  NULL                  // Comment
  );
}

// Set Sell Limit 
void SellLimit(double SLselllimit,double TPselllimit,double Lotsize)
{
// we calculate the Ask price
double Ask=NormalizeDouble(SymbolInfoDouble (_Symbol,SYMBOL_ASK) ,_Digits) ;
// we calculate the Bid price
double Bid=NormalizeDouble(SymbolInfoDouble (_Symbol,SYMBOL_BID),_Digits);
trade.SellLimit
 (
  Lotsize,                  //lot size
  (Bid+(NextPosition*_Point)),   // Price for sell limit
  _Symbol,              // Get symbol
  SLselllimit,                    //Stop loss
  TPselllimit,                    // Take profit(Bid-(200*_Point))
  ORDER_TIME_GTC,       // Expiration date
  0,                    // Expiration time
  NULL                  // Comment
 );
}
void CancelOrder()
{
// Check All order
for(int i=OrdersTotal()-1;i>=0;i--)//
{
// Get the ticket number
ulong OrderTicket=OrderGetTicket(i);
//Delete the pending order
trade.OrderDelete(OrderTicket);
}
   
  }
void CloseAllPosition()
{
for(int i=PositionsTotal()-1;i--;)//Look at all position
 {
 //Get the ticket number for the current position
 int Ticket=PositionGetTicket(i);
 //Close Position 
 trade.PositionClose(i);
 }

} 
void CloseProfitInMoney()
{
for(int i=PositionsTotal()-1; i>=0; i--) // returns the number of current positions
      if(m_position.SelectByIndex(i)) // selects the position by index for further access to its properties
        {
         double profit=m_position.Commission()+m_position.Swap()+m_position.Profit();
         if(profit>=InpProfitInMoney)
         {
            trade.PositionClose(m_position.Ticket());
            CancelOrder();
            CloseAllPosition();
            }
        }

} 
void ChangeSLFirtOrder()
{
for(int i=PositionsTotal()-1;i--;)//Look at all position
 {
 //Get the ticket number for the current position
 int Ticket=PositionGetTicket(i);
 //Close Position 
 trade.PositionClose(i);
 }
   
} 
//+------------------------------------------------------------------+
